<?php
/**
 * Copyright (c) 2014, Tinypass, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * The TPAnonApi class.
 */
class TPAnonApi  extends TPAPIBase {



    /**
     * @return authenticateRequestTPAnonApi
     */
    public function authenticateRequest(){

        return new authenticateRequestTPAnonApi($this->apiClient);
    }
}



/**
 * Authenticates a user using an email address and password
 */
class authenticateRequestTPAnonApi  extends TPAPIBase {
    protected $request = array();

    /**
     * User's email address
     * @param string $email
     * @return authenticateRequestTPAnonApi
     */
    public function email($email){
        $this->request['email'] = $email;
        return $this;
    }
    

    /**
     * User's current password
     * @param string $password
     * @return authenticateRequestTPAnonApi
     */
    public function password($password){
        $this->request['password'] = $password;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPAnonUser

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['email'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'email' ) ] = $this->apiClient->toQueryValue($this->request['email']);
        }
        if (isset($this->request['password'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'password' ) ] = $this->apiClient->toQueryValue($this->request['password']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/anon/authenticate', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPAnonUser');
        

    }

}

