<?php
/**
 * Copyright (c) 2014, Tinypass, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * The TPPublisherConsentApi class.
 */
class TPPublisherConsentApi  extends TPAPIBase {



    /**
     * @return getRequestTPPublisherConsentApi
     */
    public function getRequest(){

        return new getRequestTPPublisherConsentApi($this->apiClient);
    }


    /**
     * @return countRequestTPPublisherConsentApi
     */
    public function countRequest(){

        return new countRequestTPPublisherConsentApi($this->apiClient);
    }


    /**
     * @return updateRequestTPPublisherConsentApi
     */
    public function updateRequest(){

        return new updateRequestTPPublisherConsentApi($this->apiClient);
    }


    /**
     * @return deleteRequestTPPublisherConsentApi
     */
    public function deleteRequest(){

        return new deleteRequestTPPublisherConsentApi($this->apiClient);
    }


    /**
     * @return createRequestTPPublisherConsentApi
     */
    public function createRequest(){

        return new createRequestTPPublisherConsentApi($this->apiClient);
    }


    /**
     * @return listRequestTPPublisherConsentApi
     */
    public function listRequest(){

        return new listRequestTPPublisherConsentApi($this->apiClient);
    }
}



/**
 * Find consent box config
 */
class getRequestTPPublisherConsentApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return getRequestTPPublisherConsentApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Consent ID
     * @param string $consentId
     * @return getRequestTPPublisherConsentApi
     */
    public function consentId($consentId){
        $this->request['consentId'] = $consentId;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherConsent

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['consentId'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'consentId' ) ] = $this->apiClient->toQueryValue($this->request['consentId']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/consent/get', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherConsent');
        

    }

}


/**
 * Count consent box configs
 */
class countRequestTPPublisherConsentApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return countRequestTPPublisherConsentApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Execute request
    * @return float

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/consent/count', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'float');
        

    }

}


/**
 * Update consent box config
 */
class updateRequestTPPublisherConsentApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return updateRequestTPPublisherConsentApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Consent ID
     * @param string $consentId
     * @return updateRequestTPPublisherConsentApi
     */
    public function consentId($consentId){
        $this->request['consentId'] = $consentId;
        return $this;
    }
    

    /**
     * Consent box field ID
     * @param string $fieldId
     * @return updateRequestTPPublisherConsentApi
     */
    public function fieldId($fieldId){
        $this->request['fieldId'] = $fieldId;
        return $this;
    }
    

    /**
     * Consent box field name
     * @param string $fieldName
     * @return updateRequestTPPublisherConsentApi
     */
    public function fieldName($fieldName){
        $this->request['fieldName'] = $fieldName;
        return $this;
    }
    

    /**
     * Consent box display text
     * @param string $displayText
     * @return updateRequestTPPublisherConsentApi
     */
    public function displayText($displayText){
        $this->request['displayText'] = $displayText;
        return $this;
    }
    

    /**
     * Consent box pre-checked state
     * @param bool $preChecked
     * @return updateRequestTPPublisherConsentApi
     */
    public function preChecked($preChecked){
        $this->request['preChecked'] = $preChecked;
        return $this;
    }
    

    /**
     * Is consent box required
     * @param bool $required
     * @return updateRequestTPPublisherConsentApi
     */
    public function required($required){
        $this->request['required'] = $required;
        return $this;
    }
    

    /**
     * Consent box error message
     * @param string $errorMessage
     * @return updateRequestTPPublisherConsentApi
     */
    public function errorMessage($errorMessage){
        $this->request['errorMessage'] = $errorMessage;
        return $this;
    }
    

    /**
     * Consent box type
     * @param string $type
     * @return updateRequestTPPublisherConsentApi
     */
    public function type($type){
        $this->request['type'] = $type;
        return $this;
    }
    

    /**
     * Is consent box enabled
     * @param bool $enabled
     * @return updateRequestTPPublisherConsentApi
     */
    public function enabled($enabled){
        $this->request['enabled'] = $enabled;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherConsent

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['consentId'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'consentId' ) ] = $this->apiClient->toQueryValue($this->request['consentId']);
        }
        if (isset($this->request['fieldId'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'fieldId' ) ] = $this->apiClient->toQueryValue($this->request['fieldId']);
        }
        if (isset($this->request['fieldName'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'fieldName' ) ] = $this->apiClient->toQueryValue($this->request['fieldName']);
        }
        if (isset($this->request['displayText'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'displayText' ) ] = $this->apiClient->toQueryValue($this->request['displayText']);
        }
        if (isset($this->request['preChecked'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'preChecked' ) ] = $this->apiClient->toQueryValue($this->request['preChecked']);
        }
        if (isset($this->request['required'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'required' ) ] = $this->apiClient->toQueryValue($this->request['required']);
        }
        if (isset($this->request['errorMessage'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'errorMessage' ) ] = $this->apiClient->toQueryValue($this->request['errorMessage']);
        }
        if (isset($this->request['type'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'type' ) ] = $this->apiClient->toQueryValue($this->request['type']);
        }
        if (isset($this->request['enabled'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'enabled' ) ] = $this->apiClient->toQueryValue($this->request['enabled']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/consent/update', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherConsent');
        

    }

}


/**
 * Delete consent box config
 */
class deleteRequestTPPublisherConsentApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return deleteRequestTPPublisherConsentApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Consent ID
     * @param string $consentId
     * @return deleteRequestTPPublisherConsentApi
     */
    public function consentId($consentId){
        $this->request['consentId'] = $consentId;
        return $this;
    }
    

    /**
     * Execute request
    * @return bool

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['consentId'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'consentId' ) ] = $this->apiClient->toQueryValue($this->request['consentId']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/consent/delete', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'bool');
        

    }

}


/**
 * Create consent box config
 */
class createRequestTPPublisherConsentApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return createRequestTPPublisherConsentApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Consent box field name
     * @param string $fieldName
     * @return createRequestTPPublisherConsentApi
     */
    public function fieldName($fieldName){
        $this->request['fieldName'] = $fieldName;
        return $this;
    }
    

    /**
     * Consent box field ID
     * @param string $fieldId
     * @return createRequestTPPublisherConsentApi
     */
    public function fieldId($fieldId){
        $this->request['fieldId'] = $fieldId;
        return $this;
    }
    

    /**
     * Consent box display text
     * @param string $displayText
     * @return createRequestTPPublisherConsentApi
     */
    public function displayText($displayText){
        $this->request['displayText'] = $displayText;
        return $this;
    }
    

    /**
     * Consent box pre-checked state
     * @param bool $preChecked
     * @return createRequestTPPublisherConsentApi
     */
    public function preChecked($preChecked){
        $this->request['preChecked'] = $preChecked;
        return $this;
    }
    

    /**
     * Is consent box required
     * @param bool $required
     * @return createRequestTPPublisherConsentApi
     */
    public function required($required){
        $this->request['required'] = $required;
        return $this;
    }
    

    /**
     * Is consent box enabled
     * @param bool $enabled
     * @return createRequestTPPublisherConsentApi
     */
    public function enabled($enabled){
        $this->request['enabled'] = $enabled;
        return $this;
    }
    

    /**
     * Consent box error message
     * @param string $errorMessage
     * @return createRequestTPPublisherConsentApi
     */
    public function errorMessage($errorMessage){
        $this->request['errorMessage'] = $errorMessage;
        return $this;
    }
    

    /**
     * Consent box type
     * @param string $type
     * @return createRequestTPPublisherConsentApi
     */
    public function type($type){
        $this->request['type'] = $type;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherConsent

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['fieldName'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'fieldName' ) ] = $this->apiClient->toQueryValue($this->request['fieldName']);
        }
        if (isset($this->request['fieldId'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'fieldId' ) ] = $this->apiClient->toQueryValue($this->request['fieldId']);
        }
        if (isset($this->request['displayText'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'displayText' ) ] = $this->apiClient->toQueryValue($this->request['displayText']);
        }
        if (isset($this->request['preChecked'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'preChecked' ) ] = $this->apiClient->toQueryValue($this->request['preChecked']);
        }
        if (isset($this->request['required'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'required' ) ] = $this->apiClient->toQueryValue($this->request['required']);
        }
        if (isset($this->request['enabled'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'enabled' ) ] = $this->apiClient->toQueryValue($this->request['enabled']);
        }
        if (isset($this->request['errorMessage'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'errorMessage' ) ] = $this->apiClient->toQueryValue($this->request['errorMessage']);
        }
        if (isset($this->request['type'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'type' ) ] = $this->apiClient->toQueryValue($this->request['type']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/consent/create', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherConsent');
        

    }

}


/**
 * Find consent box configs
 */
class listRequestTPPublisherConsentApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return listRequestTPPublisherConsentApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Consent box type
     * @param string $type
     * @return listRequestTPPublisherConsentApi
     */
    public function type($type){
        $this->request['type'] = $type;
        return $this;
    }
    

    /**
     * Is consent checked by user
     * @param bool $enabled
     * @return listRequestTPPublisherConsentApi
     */
    public function enabled($enabled){
        $this->request['enabled'] = $enabled;
        return $this;
    }
    

    /**
     * Search value
     * @param string $q
     * @return listRequestTPPublisherConsentApi
     */
    public function q($q){
        $this->request['q'] = $q;
        return $this;
    }
    

    /**
     * Maximum index of returned results
     * @param int $limit
     * @return listRequestTPPublisherConsentApi
     */
    public function limit($limit){
        $this->request['limit'] = $limit;
        return $this;
    }
    

    /**
     * Offset from which to start returning results
     * @param int $offset
     * @return listRequestTPPublisherConsentApi
     */
    public function offset($offset){
        $this->request['offset'] = $offset;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherConsent[]

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['type'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'type' ) ] = $this->apiClient->toQueryValue($this->request['type']);
        }
        if (isset($this->request['enabled'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'enabled' ) ] = $this->apiClient->toQueryValue($this->request['enabled']);
        }
        if (isset($this->request['q'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'q' ) ] = $this->apiClient->toQueryValue($this->request['q']);
        }
        if (isset($this->request['limit'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'limit' ) ] = $this->apiClient->toQueryValue($this->request['limit']);
        }
        if (isset($this->request['offset'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'offset' ) ] = $this->apiClient->toQueryValue($this->request['offset']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/consent/list', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherConsent', 'array');
        

    }

}

