<?php
/**
 * Copyright (c) 2014, Tinypass, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * The TPPublisherPaymentProviderConfigurationGetWorldpayApi class.
 */
class TPPublisherPaymentProviderConfigurationGetWorldpayApi  extends TPAPIBase {



    /**
     * @return getWorldpayCCRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function getWorldpayCCRequest(){

        return new getWorldpayCCRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi($this->apiClient);
    }


    /**
     * @return getWorldpayIdealRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function getWorldpayIdealRequest(){

        return new getWorldpayIdealRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi($this->apiClient);
    }


    /**
     * @return getWorldpayPaypalRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function getWorldpayPaypalRequest(){

        return new getWorldpayPaypalRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi($this->apiClient);
    }


    /**
     * @return listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function listWorldpayPaymentMethodRequest(){

        return new listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi($this->apiClient);
    }
}



/**
 * Lists available payment provider configurations for Worldpay credit cards
 */
class getWorldpayCCRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return getWorldpayCCRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherWorldpayConfiguration

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/payment/provider/configuration/get/worldpay/cc', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherWorldpayConfiguration');
        

    }

}


/**
 * Lists available payment provider configurations for Worldpay iDeal
 */
class getWorldpayIdealRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return getWorldpayIdealRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherWorldpayConfiguration

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/payment/provider/configuration/get/worldpay/ideal', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherWorldpayConfiguration');
        

    }

}


/**
 * Lists available payment provider configurations for Worldpay PayPal
 */
class getWorldpayPaypalRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return getWorldpayPaypalRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherWorldpayConfiguration

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/payment/provider/configuration/get/worldpay/paypal', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherWorldpayConfiguration');
        

    }

}


/**
 * Lists available worldpay payment methods
 */
class listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Worldpay username
     * @param string $username
     * @return listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function username($username){
        $this->request['username'] = $username;
        return $this;
    }
    

    /**
     * Worldpay password
     * @param string $password
     * @return listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function password($password){
        $this->request['password'] = $password;
        return $this;
    }
    

    /**
     * Worldpay merchant code
     * @param string $merchantCode
     * @return listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function merchantCode($merchantCode){
        $this->request['merchantCode'] = $merchantCode;
        return $this;
    }
    

    /**
     * Worldpay installation id
     * @param string $installationId
     * @return listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function installationId($installationId){
        $this->request['installationId'] = $installationId;
        return $this;
    }
    

    /**
     * Currency code by ISO 4217 standard
     * @param string $currencyCode
     * @return listWorldpayPaymentMethodRequestTPPublisherPaymentProviderConfigurationGetWorldpayApi
     */
    public function currencyCode($currencyCode){
        $this->request['currencyCode'] = $currencyCode;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherWorldpayPaymentMethod

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['username'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'username' ) ] = $this->apiClient->toQueryValue($this->request['username']);
        }
        if (isset($this->request['password'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'password' ) ] = $this->apiClient->toQueryValue($this->request['password']);
        }
        if (isset($this->request['merchantCode'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'merchantCode' ) ] = $this->apiClient->toQueryValue($this->request['merchantCode']);
        }
        if (isset($this->request['installationId'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'installationId' ) ] = $this->apiClient->toQueryValue($this->request['installationId']);
        }
        if (isset($this->request['currencyCode'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'currencyCode' ) ] = $this->apiClient->toQueryValue($this->request['currencyCode']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/payment/provider/configuration/get/worldpay/methods', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherWorldpayPaymentMethod');
        

    }

}

