<?php
/**
 * Copyright (c) 2014, Tinypass, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 * notice, this list of conditions and the following disclaimer.
 *
 * 2. Redistributions in binary form must reproduce the above copyright
 * notice, this list of conditions and the following disclaimer in the
 * documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/**
 * The TPPublisherTaxRateApi class.
 */
class TPPublisherTaxRateApi  extends TPAPIBase {



    /**
     * @return chargeRequestTPPublisherTaxRateApi
     */
    public function chargeRequest(){

        return new chargeRequestTPPublisherTaxRateApi($this->apiClient);
    }


    /**
     * @return listRequestTPPublisherTaxRateApi
     */
    public function listRequest(){

        return new listRequestTPPublisherTaxRateApi($this->apiClient);
    }
}



/**
 * Configure tax rate for selected states
 */
class chargeRequestTPPublisherTaxRateApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return chargeRequestTPPublisherTaxRateApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * States to charge IDs
     * @param TPPublisherArray[string] $stateChargeIds
     * @return chargeRequestTPPublisherTaxRateApi
     */
    public function stateChargeIds($stateChargeIds){
        $this->request['stateChargeIds'] = $stateChargeIds;
        return $this;
    }
    

    /**
     * States to don't charge IDs
     * @param TPPublisherArray[string] $stateDontChargeIds
     * @return chargeRequestTPPublisherTaxRateApi
     */
    public function stateDontChargeIds($stateDontChargeIds){
        $this->request['stateDontChargeIds'] = $stateDontChargeIds;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherSalesTaxRateModel[]

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['stateChargeIds'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'stateChargeIds' ) ] = $this->apiClient->toQueryValue($this->request['stateChargeIds']);
        }
        if (isset($this->request['stateDontChargeIds'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'stateDontChargeIds' ) ] = $this->apiClient->toQueryValue($this->request['stateDontChargeIds']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/tax/rate/charge', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherSalesTaxRateModel', 'array');
        

    }

}


/**
 * Lists tax rates for states and charge attribute
 */
class listRequestTPPublisherTaxRateApi  extends TPAPIBase {
    protected $request = array();

    /**
     * Application aid
     * @param string $aid
     * @return listRequestTPPublisherTaxRateApi
     */
    public function aid($aid){
        $this->request['aid'] = $aid;
        return $this;
    }
    

    /**
     * Search value
     * @param string $q
     * @return listRequestTPPublisherTaxRateApi
     */
    public function q($q){
        $this->request['q'] = $q;
        return $this;
    }
    

    /**
     * Maximum index of returned results
     * @param int $limit
     * @return listRequestTPPublisherTaxRateApi
     */
    public function limit($limit){
        $this->request['limit'] = $limit;
        return $this;
    }
    

    /**
     * Offset from which to start returning results
     * @param int $offset
     * @return listRequestTPPublisherTaxRateApi
     */
    public function offset($offset){
        $this->request['offset'] = $offset;
        return $this;
    }
    

    /**
     * Execute request
    * @return TPPublisherSalesTaxRateModel[]

    */
    public function execute(){
        $queryParams = array();
        if (isset($this->request['aid'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'aid' ) ] = $this->apiClient->toQueryValue($this->request['aid']);
        }
        if (isset($this->request['q'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'q' ) ] = $this->apiClient->toQueryValue($this->request['q']);
        }
        if (isset($this->request['limit'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'limit' ) ] = $this->apiClient->toQueryValue($this->request['limit']);
        }
        if (isset($this->request['offset'])) {
            $queryParams[ $this->apiClient->toQueryParameter( 'offset' ) ] = $this->apiClient->toQueryValue($this->request['offset']);
        }
        


        $headerParams = array();
        $headerParams['Accept'] = '(mediaType,application/json)';
        $headerParams['Content-Type'] = '';
        


        // make the API Call
        $response = $this->apiClient->callAPI('/publisher/tax/rate/list', 'GET', $queryParams, $headerParams);

        if ($response->code != 0) {
            return $response;
        }

        return $this->apiClient->deserialize($response, 'TPPublisherSalesTaxRateModel', 'array');
        

    }

}

